netapp_ontap.models.data_engine_event_resource API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.data_engine_event_resource`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class DataEngineEventResourceSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the DataEngineEventResource object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `name: str GET POST PATCH`

    The name of the resource.

    Example: Workspace 1

  `type: str GET POST PATCH`

    The type of the data engine resource.

    Valid choices:

    - workspace
    - data_source
    - data_collection
    - policy
    - custom
  `uuid: str GET POST PATCH`

    The unique identifier of the resource.

    Example: 123e4567-e89b-12d3-a456-426614174000